package com.zjsgfa.project.zjsgfa.mapper;

import com.zjsgfa.project.zjsgfa.domain.Dcmbgl;

import java.util.List;

/**
 * 导出word模板管理Mapper接口
 * 
 * @author ruoyi
 * @date 2026-01-19
 */
public interface DcmbglMapper 
{
    /**
     * 查询导出word模板管理
     * 
     * @param id 导出word模板管理主键
     * @return 导出word模板管理
     */
    public Dcmbgl selectDcmbglById(Long id);

    /**
     * 查询导出word模板管理列表
     * 
     * @param dcmbgl 导出word模板管理
     * @return 导出word模板管理集合
     */
    public List<Dcmbgl> selectDcmbglList(Dcmbgl dcmbgl);

    /**
     * 新增导出word模板管理
     * 
     * @param dcmbgl 导出word模板管理
     * @return 结果
     */
    public int insertDcmbgl(Dcmbgl dcmbgl);

    /**
     * 修改导出word模板管理
     * 
     * @param dcmbgl 导出word模板管理
     * @return 结果
     */
    public int updateDcmbgl(Dcmbgl dcmbgl);

    /**
     * 删除导出word模板管理
     * 
     * @param id 导出word模板管理主键
     * @return 结果
     */
    public int deleteDcmbglById(Long id);

    /**
     * 批量删除导出word模板管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDcmbglByIds(Long[] ids);
}
